==> open-cluster-management-discovery-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/discovery/v1alpha1/DiscoveryConfigSpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.discovery.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DiscoveryConfigSpecBuilder extends DiscoveryConfigSpecFluentImpl<DiscoveryConfigSpecBuilder> implements VisitableBuilder<DiscoveryConfigSpec,DiscoveryConfigSpecBuilder>{
  public DiscoveryConfigSpecBuilder() {
    this(false);
  }
  public DiscoveryConfigSpecBuilder(Boolean validationEnabled) {
    this(new DiscoveryConfigSpec(), validationEnabled);
  }
  public DiscoveryConfigSpecBuilder(DiscoveryConfigSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public DiscoveryConfigSpecBuilder(DiscoveryConfigSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DiscoveryConfigSpec(), validationEnabled);
  }
  public DiscoveryConfigSpecBuilder(DiscoveryConfigSpecFluent<?> fluent,DiscoveryConfigSpec instance) {
    this(fluent, instance, false);
  }
  public DiscoveryConfigSpecBuilder(DiscoveryConfigSpecFluent<?> fluent,DiscoveryConfigSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCredential(instance.getCredential());
      fluent.withFilters(instance.getFilters());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DiscoveryConfigSpecBuilder(DiscoveryConfigSpec instance) {
    this(instance,false);
  }
  public DiscoveryConfigSpecBuilder(DiscoveryConfigSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCredential(instance.getCredential());
      this.withFilters(instance.getFilters());
    }
    this.validationEnabled = validationEnabled; 
  }
  DiscoveryConfigSpecFluent<?> fluent;
  Boolean validationEnabled;
  public DiscoveryConfigSpec build() {
    DiscoveryConfigSpec buildable = new DiscoveryConfigSpec(fluent.getCredential(),fluent.getFilters());
    return buildable;
  }
  
}

==> open-cluster-management-discovery-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/discovery/v1alpha1/DiscoveryConfigSpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.discovery.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DiscoveryConfigSpecBuilder extends DiscoveryConfigSpecFluent<DiscoveryConfigSpecBuilder> implements VisitableBuilder<DiscoveryConfigSpec,DiscoveryConfigSpecBuilder>{
  public DiscoveryConfigSpecBuilder() {
    this(false);
  }
  public DiscoveryConfigSpecBuilder(Boolean validationEnabled) {
    this(new DiscoveryConfigSpec(), validationEnabled);
  }
  public DiscoveryConfigSpecBuilder(DiscoveryConfigSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public DiscoveryConfigSpecBuilder(DiscoveryConfigSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DiscoveryConfigSpec(), validationEnabled);
  }
  public DiscoveryConfigSpecBuilder(DiscoveryConfigSpecFluent<?> fluent,DiscoveryConfigSpec instance) {
    this(fluent, instance, false);
  }
  public DiscoveryConfigSpecBuilder(DiscoveryConfigSpecFluent<?> fluent,DiscoveryConfigSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new DiscoveryConfigSpec());

    if (instance != null) {
      fluent.withCredential(instance.getCredential());
      fluent.withFilters(instance.getFilters());
      fluent.withCredential(instance.getCredential());
      fluent.withFilters(instance.getFilters());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DiscoveryConfigSpecBuilder(DiscoveryConfigSpec instance) {
    this(instance,false);
  }
  public DiscoveryConfigSpecBuilder(DiscoveryConfigSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new DiscoveryConfigSpec());

    if (instance != null) {
      this.withCredential(instance.getCredential());
      this.withFilters(instance.getFilters());
      this.withCredential(instance.getCredential());
      this.withFilters(instance.getFilters());
    }
    this.validationEnabled = validationEnabled; 
  }
  DiscoveryConfigSpecFluent<?> fluent;
  Boolean validationEnabled;
  public DiscoveryConfigSpec build() {
    DiscoveryConfigSpec buildable = new DiscoveryConfigSpec(fluent.getCredential(),fluent.buildFilters());
    return buildable;
  }
  
}
